/*
	$Id: globals.c,v 1.8 2003/09/06 02:16:47 Treize Exp $
	ROX-Menu - Simple application menu applet for ROX desktop environment.
	Copyright (C) 2001 Leandro Pereira <leandro@linuxmag.com.br>
	Copyright (C) 2003 Peter Geer <geerp@cs.sunyit.edu>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
	
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/stat.h>

#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include "globals.h"
#include "choices.h"

#include "Icons/menu.xpm"
#include "Icons/menu2.xpm"

/* This function adapted from the pixmaps.c file in ROX-Filer 2.0.1
   by Thomas Leonard. */
GdkPixbuf *scale_pixbuf(GdkPixbuf *src, int max_w, int max_h, int uncond)
{
	int	w, h;
	w = gdk_pixbuf_get_width(src);
	h = gdk_pixbuf_get_height(src);

	if (w <= max_w && h <= max_h && !uncond)
	{
		gdk_pixbuf_ref(src);
		return src;
	}
	else
	{
		float scale_x = ((float) w) / max_w;
		float scale_y = ((float) h) / max_h;
		float scale = MAX(scale_x, scale_y);
		int dest_w = w / scale;
		int dest_h = h / scale;
		
		return gdk_pixbuf_scale_simple(src,
						MAX(dest_w, 1),
						MAX(dest_h, 1),
						GDK_INTERP_BILINEAR);
	}
}

void change_menu_pixmap(gint state)
{
	gchar *ico;
	char ** def;

	if (GPOINTER_TO_INT(state) == ENTER) {
		ico = menu_file_on;
		def = menu2_xpm;
	} else {
		ico = menu_file_off;
		def = menu_xpm;
	}
	
   if (GTK_IS_WIDGET(_pixmap) )
		gtk_container_remove(GTK_CONTAINER(button), _pixmap);
   _pixmap = create_pixmap(ico, def, icon_width, icon_height, TRUE);
   gtk_widget_show(_pixmap);
   gtk_container_add(GTK_CONTAINER(button), _pixmap);
}

GtkWidget *create_pixmap(char *path, char ** default_icon, 
                         gint width, gint height, gint unconditional)
{
   GtkWidget *pixmap;
   GdkPixbuf *pixbuf, *pixbuf_scaled;
   struct stat info;

   if (!stat(path, &info)) {
		pixbuf = gdk_pixbuf_new_from_file(path, NULL);
   } else {
		pixbuf = gdk_pixbuf_new_from_xpm_data((const char **) default_icon);
   }
	pixbuf_scaled = scale_pixbuf(pixbuf, width, height, unconditional);
   
	pixmap = gtk_image_new_from_pixbuf(GDK_PIXBUF(pixbuf_scaled));
	
	if (GDK_IS_PIXBUF(pixbuf_scaled) )gdk_pixbuf_unref(pixbuf_scaled);
	if (GDK_IS_PIXBUF(pixbuf) ) gdk_pixbuf_unref(pixbuf);
    
	return pixmap;
}

/* Write the config to a file. 
   Adapted from Steven Watson's DemoApplet. */
void write_config(void) {

	gchar *fname;

	/* Use the choices system to get the name to save to */
	fname=choices_find_path_save("options", app_name, TRUE);

	if(fname) {
		FILE *out;

		out=fopen(fname, "w");
		if(out) {

			/* Write config here... */
			fprintf(out, ("icon_width = %d\n"), icon_width);
			fprintf(out, ("icon_height = %d\n"), icon_height);
			fprintf(out, ("menu_file_on = %s\n"), menu_file_off);
			fprintf(out, ("menu_file_off = %s\n"), menu_file_off);
			fprintf(out, ("groups_on_bottom = %d\n"), groups_on_bottom);
			fprintf(out, ("strip_number = %d\n"), strip_number);
      
			fclose(out);
		}

		g_free(fname);
	}
}
/* Read in the config.
   Adapted from Steven Watson's DemoApplet. */
void read_config(void) {

	guchar *fname;

	/* Use the choices system to locate the file to read */
	fname=choices_find_path_load("options", app_name);

	if(fname) {
		FILE *in;
		in=fopen(fname, "r");
		if(in) {
			char buf[1024], *line;
			char *end, *start;
			int val;

			do {
				line=fgets(buf, sizeof(buf), in);
				if(!line)
					break;
				end=strchr(line, '\n');
				if(end)
					*end=0;
				end=strchr(line, '#');  /* everything after # is a comment */
				if(end)
					*end=0;

				/* Process the line here... */
				if( strstr(line, "icon_width") ) {
					
					start = strstr(line, "=");
					start = (char*) start+1;
					val = atoi(start);
					if (val > 0) icon_width = val;

				} else if ( strstr(line, "icon_height") ) {

					start = strstr(line, "=");
					start = (char*) start+1;
					val = atoi(start);
					if (val > 0) icon_height = val;

				} else if ( strstr(line, "menu_file_on") ) {

					start = strstr(line, "=");
					start = (char*) start+1;
					while (start[0] != '/' && start[0] != '\0')
						start = (char*) start+1;
					menu_file_on = g_strdup(start);
					
				} else if ( strstr(line, "menu_file_off") ) {

					start = strstr(line, "=");
					start = (char*) start+1;
					while (start[0] != '/' && start[0] != '\0')
						start = (char*) start+1;
					menu_file_off = g_strdup(start);
					
				} else if ( strstr(line, "groups_on_bottom") ) {

					start = strstr(line, "=");
					start = (char*) start+1;
					val = atoi(start);
					if (val >= 0) groups_on_bottom = val;
				
				} else if ( strstr(line, "strip_number") ) {

					start = strstr(line, "=");
					start = (char*) start+1;
					val = atoi(start);
					if (val >= 0) strip_number = val;
				}
			} while(!feof(in));

			fclose(in);
		}

		g_free(fname);
	}
}

